<?xml version="1.0" encoding="utf-8"?>
<!-- teip4to5.xsl -->
<!-- Version 1.4 -->
<!-- Andreas Nolda 2018-11-30 -->
<!-- based on a stylesheet by Sebastian Rahtz -->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.tei-c.org/ns/1.0"
                xmlns:n="http://andreas.nolda.org/ns/tei"
                xmlns:mei="http://www.music-encoding.org/ns/mei"
                xmlns:m="http://www.w3.org/1998/Math/MathML"
                xmlns:xi="http://www.w3.org/2001/XInclude"
                exclude-result-prefixes="mei m xi">

<xsl:output encoding="utf-8"
            method="xml"/>

<xsl:template match="*">
  <xsl:choose>
    <xsl:when test="namespace-uri()=''">
      <xsl:element namespace="http://www.tei-c.org/ns/1.0" name="{local-name()}">
        <xsl:apply-templates select="* |
                                     @* |
                                     processing-instruction() |
                                     comment() |
                                     text()"/>
      </xsl:element>
    </xsl:when>
    <xsl:otherwise>
      <xsl:copy>
        <xsl:apply-templates select="* |
                                     @* |
                                     processing-instruction() |
                                     comment() |
                                     text()"/>
      </xsl:copy>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="@* |
                     processing-instruction() |
                     comment()">
  <xsl:copy/>
</xsl:template>

<xsl:template match="@TEIform"/>

<xsl:template match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template match="/TEI.2">
  <TEI xmlns="http://www.tei-c.org/ns/1.0">
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </TEI>
</xsl:template>

<xsl:template match="/div |
                     /div0 |
                     /div1 |
                     /div2 |
                     /div3 |
                     /div4 |
                     /div5 |
                     /div6 |
                     /div7">
  <div xmlns="http://www.tei-c.org/ns/1.0">
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </div>
</xsl:template>

<xsl:template match="/bibl">
  <bibl xmlns="http://www.tei-c.org/ns/1.0" type="reference">
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </bibl>
</xsl:template>

<xsl:template name="initials">
  <xsl:value-of select="substring(.//persName/forename,1,1)"/>
  <xsl:value-of select="substring(.//persName/surname,1,1)"/>
</xsl:template>

<xsl:template match="fileDesc/titleStmt/author |
                     fileDesc/titleStmt/respStmt">
  <xsl:element name="{name()}">
    <xsl:attribute name="xml:id">
      <xsl:call-template name="initials"/>
    </xsl:attribute>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </xsl:element>
</xsl:template>

<xsl:template match="revisionDesc">
  <revisionDesc>
    <xsl:apply-templates>
      <xsl:sort select="position()"
                data-type="number"
                order="descending"/>
    </xsl:apply-templates>
  </revisionDesc>
</xsl:template>

<xsl:template match="revisionDesc/change">
  <change>
    <xsl:apply-templates select="date |
                                 respStmt"/>
    <xsl:apply-templates select="item"/>
  </change>
</xsl:template>

<xsl:template match="change/date">
  <xsl:attribute name="when">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="change/respStmt">
  <xsl:if test=".//persName">
    <xsl:attribute name="who">
      <xsl:text>#</xsl:text>
      <xsl:call-template name="initials"/>
    </xsl:attribute>
  </xsl:if>
</xsl:template>

<xsl:template match="change/item">
  <xsl:apply-templates select="* |
                               @* |
                               processing-instruction() |
                               comment() |
                               text()"/>
</xsl:template>

<xsl:template match="revisionDesc/list">
  <xsl:apply-templates select="label"/>
</xsl:template>

<xsl:template match="revisionDesc/list/label">
  <xsl:if test="position()&gt;1">
    <xsl:text>&#xA;</xsl:text>
  </xsl:if>
  <change>
    <xsl:attribute name="who">
      <xsl:text>#</xsl:text>
      <xsl:for-each select="../../../fileDesc/titleStmt/respStmt[1]">
        <xsl:call-template name="initials"/>
      </xsl:for-each>
    </xsl:attribute>
    <xsl:apply-templates select="following-sibling::item[1]"/>
    <xsl:apply-templates select="* |
                                 comment() |
                                 text()"/>
  </change>
</xsl:template>

<xsl:template match="revisionDesc/list/item">
  <xsl:apply-templates select="list/label"/>
</xsl:template>

<xsl:template match="revisionDesc/list/item/list/label[.='begonnen']">
  <xsl:attribute name="from">
    <xsl:value-of select="following-sibling::item[1]/date"/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="revisionDesc/list/item/list/label[.='abgeschlossen']">
  <xsl:attribute name="to">
    <xsl:value-of select="following-sibling::item[1]/date"/>
  </xsl:attribute>
  <!-- <xsl:attribute name="status">finished</xsl:attribute> -->
</xsl:template>

<xsl:template name="prefix-hash-sign">
  <xsl:param name="argument"/>
  <xsl:choose>
    <xsl:when test="contains($argument,' ')">
      <xsl:text>#</xsl:text>
      <xsl:value-of select="substring-before($argument,' ')"/>
      <xsl:text> </xsl:text>
      <xsl:call-template name="prefix-hash-sign">
        <xsl:with-param name="argument">
          <xsl:value-of select="substring-after($argument,' ')"/>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>#</xsl:text>
      <xsl:value-of select="$argument"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="@ana |
                     @copyOf |
                     @corresp |
                     @exclude |
                     *[not(self::dateRange)]/@from |
                     @next |
                     @prev |
                     @render |
                     @resp |
                     @sameAs |
                     @select |
                     @startid |
                     @target |
                     *[not(self::dateRange)]/@to">
  <xsl:attribute name="{name()}">
    <xsl:call-template name="prefix-hash-sign">
      <xsl:with-param name="argument">
        <xsl:value-of select="."/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:attribute>
</xsl:template>

<xsl:template match="graphic/@url">
  <xsl:attribute name="url">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="@url">
  <xsl:attribute name="target">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="date/@value">
  <xsl:attribute name="when">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="@crdate">
  <xsl:attribute name="when">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="@id">
  <xsl:attribute name="xml:id">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="@lang">
  <xsl:variable name="base">
    <xsl:choose>
      <xsl:when test="contains(.,'.')">
        <xsl:value-of select="substring-before(.,'.')"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="."/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="suffix">
    <xsl:value-of select="substring-after(.,'.')"/>
  </xsl:variable>
  <xsl:attribute name="xml:lang">
    <xsl:choose>
       <xsl:when test="$base='ara'">ar</xsl:when>
       <xsl:when test="$base='bul'">bg</xsl:when>
       <xsl:when test="$base='che'">ce</xsl:when>
       <xsl:when test="$base='chi'">zh</xsl:when>
       <xsl:when test="$base='cze'">cs</xsl:when>
       <xsl:when test="$base='dan'">da</xsl:when>
       <xsl:when test="$base='deu'">de</xsl:when>
       <xsl:when test="$base='eng'">en</xsl:when>
       <xsl:when test="$base='fao'">fo</xsl:when>
       <xsl:when test="$base='fin'">fi</xsl:when>
       <xsl:when test="$base='fra'">fr</xsl:when>
       <xsl:when test="$base='fry'">fy</xsl:when>
       <xsl:when test="$base='genh'">de-x-frnhd</xsl:when>
       <xsl:when test="$base='glg'">gl</xsl:when>
       <xsl:when test="$base='gre'">el</xsl:when>
       <xsl:when test="$base='grn'">gn</xsl:when>
       <xsl:when test="$base='hau'">ha</xsl:when>
       <xsl:when test="$base='heb'">he</xsl:when>
       <xsl:when test="$base='hin'">hi</xsl:when>
       <xsl:when test="$base='hun'">hu</xsl:when>
       <xsl:when test="$base='igbo'">ig</xsl:when>
       <xsl:when test="$base='ieu'">ine</xsl:when>
       <xsl:when test="$base='isl'">is</xsl:when>
       <xsl:when test="$base='ita'">it</xsl:when>
       <xsl:when test="$base='jpn'">ja</xsl:when>
       <xsl:when test="$base='kal'">kl</xsl:when>
       <xsl:when test="$base='kor'">ko</xsl:when>
       <xsl:when test="$base='lat'">la</xsl:when>
       <xsl:when test="$base='may'">ml</xsl:when>
       <xsl:when test="$base='mri'">mi</xsl:when>
       <xsl:when test="$base='nav'">nv</xsl:when>
       <xsl:when test="$base='nld'">nl</xsl:when>
       <xsl:when test="$base='nor'">no</xsl:when>
       <xsl:when test="$base='per'">fa</xsl:when>
       <xsl:when test="$base='pol'">pl</xsl:when>
       <xsl:when test="$base='por'">pt</xsl:when>
       <xsl:when test="$base='ron'">ro</xsl:when>
       <xsl:when test="$base='rus'">ru</xsl:when>
       <xsl:when test="$base='san'">sa</xsl:when>
       <xsl:when test="$base='scr'">sh</xsl:when>
       <xsl:when test="$base='spa'">es</xsl:when>
       <xsl:when test="$base='swa'">sw</xsl:when>
       <xsl:when test="$base='swe'">sv</xsl:when>
       <xsl:when test="$base='tur'">tr</xsl:when>
       <xsl:otherwise>
         <xsl:value-of select="$base"/>
       </xsl:otherwise>
     </xsl:choose>
     <xsl:if test="$suffix='latin'">-Latn</xsl:if>
     <xsl:if test="$suffix='ipa'">-fonipa</xsl:if>
  </xsl:attribute>
</xsl:template>

<xsl:template match="@xml:base">
  <xsl:attribute name="xml:base">
    <xsl:choose>
      <xsl:when test="starts-with(.,'file://')">
        <xsl:value-of select="substring-after(.,'file://')"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="."/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:attribute>
</xsl:template>

<xsl:template match="@prefix">
  <xsl:attribute name="n:prefix">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="person">
  <person>
    <xsl:apply-templates select="@*"/>
    <xsl:text>&#xA;</xsl:text>
    <xsl:if test="persName">
      <xsl:apply-templates select="persName"/>
      <xsl:text>&#xA;</xsl:text>
    </xsl:if>
    <xsl:if test="occupation">
      <xsl:apply-templates select="occupation"/>
      <xsl:text>&#xA;</xsl:text>
    </xsl:if>
    <xsl:if test="residence">
      <xsl:apply-templates select="residence"/>
      <xsl:text>&#xA;</xsl:text>
    </xsl:if>
    <xsl:if test="firstLang |
                  langKnown">
      <langKnowledge>
        <xsl:text>&#xA;</xsl:text>
        <xsl:apply-templates select="firstLang |
                                     langKnown"/>
      </langKnowledge>
      <xsl:text>&#xA;</xsl:text>
    </xsl:if>
  </person>
</xsl:template>

<xsl:template name="tag-att">
  <xsl:attribute name="tag">
    <xsl:choose>
      <xsl:when test="contains(.,'Bulgarisch')">bg</xsl:when>
      <xsl:when test="contains(.,'Chinesisch')">zh</xsl:when>
      <xsl:when test="contains(.,'Dänisch')">da</xsl:when>
      <xsl:when test="contains(.,'Deutsch')">de</xsl:when>
      <xsl:when test="contains(.,'Französisch')">fr</xsl:when>
      <xsl:when test="contains(.,'Japanisch')">ja</xsl:when>
      <xsl:when test="contains(.,'Niederländisch')">nl</xsl:when>
      <xsl:when test="contains(.,'Polnisch')">pl</xsl:when>
      <xsl:when test="contains(.,'Russisch')">ru</xsl:when>
      <xsl:when test="contains(.,'Schwedisch')">sv</xsl:when>
      <xsl:when test="contains(.,'Ungarisch')">hu</xsl:when>
    </xsl:choose>
  </xsl:attribute>
</xsl:template>

<xsl:template match="firstLang">
  <langKnown level="native">
    <xsl:call-template name="tag-att"/>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </langKnown>
  <xsl:text>&#xA;</xsl:text>
</xsl:template>

<xsl:template match="langKnown">
  <langKnown>
    <xsl:call-template name="tag-att"/>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </langKnown>
  <xsl:text>&#xA;</xsl:text>
</xsl:template>

<xsl:template match="div0 |
                     div1 |
                     div2 |
                     div3 |
                     div4 |
                     div5 |
                     div6 |
                     div7">
  <div>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </div>
</xsl:template>

<xsl:template match="note[@connect]">
  <ab type="argument">
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </ab>
</xsl:template>

<xsl:template match="note/@connect">
  <xsl:attribute name="subtype">
    <xsl:choose>
      <xsl:when test=".='but'">
        <xsl:text>objection</xsl:text>
      </xsl:when>
      <xsl:when test=".='if'">
        <xsl:text>premise</xsl:text>
      </xsl:when>
      <xsl:when test=".='then'">
        <xsl:text>conclusion</xsl:text>
      </xsl:when>
    </xsl:choose>
  </xsl:attribute>
</xsl:template>

<xsl:template match="corr[@sic]">
  <choice>
    <xsl:text>&#xA;</xsl:text>
    <corr>
      <xsl:apply-templates select="* |
                                   @*[not(name()='sic')] |
                                   processing-instruction() |
                                   comment() |
                                   text()"/>
    </corr>
    <xsl:text>&#xA;</xsl:text>
    <sic>
      <xsl:value-of select="@sic"/>
    </sic>
    <xsl:text>&#xA;</xsl:text>
  </choice>
</xsl:template>

<xsl:template match="sic[@corr]">
  <choice>
    <xsl:apply-templates select="@rend"/><!-- rend="all" -->
    <xsl:text>&#xA;</xsl:text>
    <sic>
      <xsl:apply-templates select="* |
                                   @*[not(name()='corr' or
                                          name()='rend')] |
                                   processing-instruction() |
                                   comment() |
                                   text()"/>
    </sic>
    <xsl:text>&#xA;</xsl:text>
    <corr>
      <xsl:value-of select="@corr"/>
    </corr>
    <xsl:text>&#xA;</xsl:text>
  </choice>
</xsl:template>

<xsl:template match="abbr[@expan]">
  <choice>
    <xsl:text>&#xA;</xsl:text>
    <abbr>
      <xsl:apply-templates select="* |
                                   @*[not(name()='expan')] |
                                   processing-instruction() |
                                   comment() |
                                   text()"/>
    </abbr>
    <xsl:text>&#xA;</xsl:text>
    <expan>
      <xsl:value-of select="@expan"/>
    </expan>
    <xsl:text>&#xA;</xsl:text>
  </choice>
</xsl:template>

<xsl:template match="expan[@abbr]">
  <choice>
    <xsl:text>&#xA;</xsl:text>
    <expan>
      <xsl:apply-templates select="* |
                                   @*[not(name()='abbr')] |
                                   processing-instruction() |
                                   comment() |
                                   text()"/>
    </expan>
    <xsl:text>&#xA;</xsl:text>
    <abbr>
      <xsl:value-of select="@abbr"/>
    </abbr>
    <xsl:text>&#xA;</xsl:text>
  </choice>
</xsl:template>

<xsl:template match="orig[@reg]">
  <choice>
    <xsl:text>&#xA;</xsl:text>
    <orig>
      <xsl:apply-templates select="* |
                                   @*[not(name()='reg')] |
                                   processing-instruction() |
                                   comment() |
                                   text()"/>
    </orig>
    <xsl:text>&#xA;</xsl:text>
    <reg>
      <xsl:value-of select="@reg"/>
    </reg>
    <xsl:text>&#xA;</xsl:text>
  </choice>
</xsl:template>

<xsl:template match="reg[@orig]">
  <choice>
    <xsl:text>&#xA;</xsl:text>
    <reg>
      <xsl:apply-templates select="* |
                                   @*[not(name()='orig')] |
                                   processing-instruction() |
                                   comment() |
                                   text()"/>
    </reg>
    <xsl:text>&#xA;</xsl:text>
    <orig>
      <xsl:value-of select="@orig"/>
    </orig>
    <xsl:text>&#xA;</xsl:text>
  </choice>
</xsl:template>

<xsl:template match="gloss |
                     seg">
  <xsl:element name="{name()}">
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </xsl:element>
</xsl:template>

<xsl:template match="mentioned">
  <mentioned>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </mentioned>
</xsl:template>

<xsl:template match="mentioned/@type">
  <xsl:attribute name="n:type">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="title/@type">
  <xsl:attribute name="type">
    <xsl:choose>
      <xsl:when test=".='descriptive'">
        <xsl:text>desc</xsl:text>
      </xsl:when>
      <xsl:when test=".='subordinate'">
        <xsl:text>sub</xsl:text>
      </xsl:when>
      <xsl:when test=".='parallel'">
        <xsl:text>alt</xsl:text>
      </xsl:when>
      <xsl:when test=".='parallel.subordinate'">
        <xsl:text>alt.sub</xsl:text>
      </xsl:when>
    </xsl:choose>
  </xsl:attribute>
</xsl:template>

<xsl:template match="comment |
                     dialogue |
                     eCell |
                     eRow |
                     eTable |
                     example |
                     glossed |
                     listDisplayed |
                     summary |
                     theorem">
  <xsl:element name="n:{name()}">
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </xsl:element>
</xsl:template>

<xsl:template match="cmt |
                     input |
                     kw |
                     var">
  <ident>
    <xsl:attribute name="type">
      <xsl:choose>
        <xsl:when test="name()='cmt'">comment</xsl:when>
        <xsl:when test="name()='kw'">keyword</xsl:when>
        <xsl:when test="name()='var'">variable</xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="name()"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:attribute>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </ident>
</xsl:template>

<xsl:template match="bibl">
  <bibl type="reference">
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </bibl>
</xsl:template>

<xsl:template match="bibl/@type">
  <xsl:attribute name="subtype">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="biblScope/@type">
  <xsl:attribute name="unit">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template name="bibl-paren">
  <xsl:attribute name="type">
    <xsl:choose>
      <xsl:when test="contains(@type,'.in.par')">
        <xsl:value-of select="substring-before(@type,'.in.par')"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="@type"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:attribute>
</xsl:template>

<xsl:template match="ref[starts-with(@type,'bibl') or
                         starts-with(@type,'source')]">
  <bibl type="citation">
    <xsl:if test="contains(@type,'.in.par')">
      <xsl:attribute name="rend">no.paren</xsl:attribute>
    </xsl:if>
    <xsl:text>&#xA;</xsl:text>
    <ptr>
      <xsl:call-template name="bibl-paren"/>
      <xsl:apply-templates select="@*[not(name()='type')]"/>
    </ptr>
    <xsl:text>&#xA;</xsl:text>
    <citedRange>
      <xsl:apply-templates select="* |
                                   processing-instruction() |
                                   comment() |
                                   text()"/>
    </citedRange>
    <xsl:text>&#xA;</xsl:text>
  </bibl>
</xsl:template>

<xsl:template match="ptr[starts-with(@type,'bibl') or
                         starts-with(@type,'source')]">
  <bibl type="citation">
    <xsl:if test="contains(@type,'.in.par')">
      <xsl:attribute name="rend">no.paren</xsl:attribute>
    </xsl:if>
    <xsl:text>&#xA;</xsl:text>
    <ptr>
      <xsl:call-template name="bibl-paren"/>
      <xsl:apply-templates select="@*[not(name()='type')]"/>
    </ptr>
    <xsl:text>&#xA;</xsl:text>
  </bibl>
</xsl:template>

<xsl:template match="ref[@type='speaker' or
                         @type='subject']">
  <ref>
    <xsl:text>&#xA;</xsl:text>
    <ptr>
      <xsl:apply-templates select="@*"/>
    </ptr>
    <xsl:text>&#xA;</xsl:text>
    <xsl:apply-templates select="* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
    <xsl:text>&#xA;</xsl:text>
  </ref>
</xsl:template>

<xsl:template match="xref">
  <ref>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </ref>
</xsl:template>

<xsl:template match="xptr">
  <ptr>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </ptr>
</xsl:template>

<xsl:template match="pubPlace">
  <pubPlace>
    <placeName>
      <xsl:text>&#xA;</xsl:text>
      <xsl:choose>
        <xsl:when test="contains(.,',')">
          <settlement>
            <xsl:value-of select="substring-before(.,',')"/>
          </settlement>
          <xsl:text>&#xA;</xsl:text>
          <region>
            <xsl:variable name="abbr">
              <xsl:value-of select="substring-after(.,', ')"/>
            </xsl:variable>
            <xsl:choose>
              <xsl:when test="$abbr='Conn.'">
                <xsl:text>Connecticut</xsl:text>
              </xsl:when>
              <xsl:when test="$abbr='D.C.'">
                <xsl:text>District of Columbia</xsl:text>
              </xsl:when>
              <xsl:when test="$abbr='Ill.'">
                <xsl:text>Illinois</xsl:text>
              </xsl:when>
              <xsl:when test="$abbr='Mass.'">
                <xsl:text>Massachusetts</xsl:text>
              </xsl:when>
              <xsl:when test="$abbr='N.J.'">
                <xsl:text>New Jersey</xsl:text>
              </xsl:when>
              <xsl:when test="$abbr='S.C.'">
                <xsl:text>South Carolina</xsl:text>
              </xsl:when>
              <xsl:when test="$abbr='VA'">
                <xsl:text>Virginia</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="$abbr"/>
              </xsl:otherwise>
            </xsl:choose>
          </region>
        </xsl:when>
        <xsl:otherwise>
          <settlement>
            <xsl:value-of select="."/>
          </settlement>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:text>&#xA;</xsl:text>
    </placeName>
    <xsl:apply-templates select="comment()"/>
  </pubPlace>
</xsl:template>

<xsl:template match="extent">
  <extent>
    <xsl:text>&#xA;</xsl:text>
    <measure>
      <xsl:apply-templates select="* |
                                   @* |
                                   processing-instruction() |
                                   comment() |
                                   text()"/>
    </measure>
    <xsl:text>&#xA;</xsl:text>
  </extent>
</xsl:template>

<xsl:template match="extent/@type">
  <xsl:attribute name="unit">
    <xsl:value-of select="."/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="mei:score">
  <mei:mdiv>
    <xsl:text>&#xA;</xsl:text>
    <mei:score>
      <xsl:apply-templates select="* |
                                   @* |
                                   processing-instruction() |
                                   comment() |
                                   text()"/>
    </mei:score>
    <xsl:text>&#xA;</xsl:text>
  </mei:mdiv>
</xsl:template>

<xsl:template match="mei:staffDef/@scale">
  <xsl:attribute name="scale">
    <xsl:value-of select="concat(. * 100,'%')"/>
  </xsl:attribute>
</xsl:template>

<xsl:template match="mei:n">
  <mei:note>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </mei:note>
</xsl:template>

<xsl:template match="mei:r">
  <mei:rest>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </mei:rest>
</xsl:template>

<xsl:template match="mei:spc">
  <mei:space>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </mei:space>
</xsl:template>

<xsl:template match="mei:*">
  <xsl:element name="mei:{local-name(.)}">
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </xsl:element>
</xsl:template>


<xsl:template match="m:*">
  <xsl:element name="m:{local-name(.)}">
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </xsl:element>
</xsl:template>

<xsl:template match="xi:include">
  <xi:include>
    <xsl:apply-templates select="* |
                                 @* |
                                 processing-instruction() |
                                 comment() |
                                 text()"/>
  </xi:include>
</xsl:template>
</xsl:stylesheet>
